@@ -5,8 +5,8 @@
 
 # change 'tests => 1' to 'tests => last_test_to_print';
 
-use Test;
-BEGIN { plan tests => 2 };
+use Test::More;
+
 use Regexp::Profanity::US;
 use Data::Dumper;
 ok(1); # If we made it this far, we're ok.
@@ -21,8 +21,14 @@ my $string = 'punk-pussy-ass@Python-using-bitch.com';
 
 my @R = profane_list($string);
 
+#warn "matched: @R";
+
+like ( "@R" , qr/punk-pussy-ass.+bitch/, 'must find 2 profane words in string' );
+
 $string = 'http://www.Javaisalanguagefordicklesspoopyfacedfuckheads.com';
 
 $R = profane($string, 'definite');
 
-ok ($R, 'dickless');
+is ($R, 'dickless', 'must find one profane word');
+
+done_testing;
